import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');
//drawing The spherical Mercator projection.
const projection = geoMercator()
  .translate([-700, 560]) // poistion of map
  .scale([850]); // zoom

// given a JSON geometry object, to generates an SVG path
const pathGenerator = geoPath().projection(projection);

//Array of ten categorical colors which is returned as RGB hexadecimal strings. 
const colorScale = scaleOrdinal(schemeCategory10);

//loading the data
json('https://gist.githubusercontent.com/kakumanusreya/0ef9de7836230b071a364bc180316090/raw/cd0762fb49f4f0af844defd2dd54021ebca8903e/india.json'
).then((data) => {
  //extracting data of states
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
  
countryShapes.features.shift()

	//Renders the path to a Canvas by appending path generated by pathgenerator to svg
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

  //Rendering the text with state names in the middle of state
  svg
    .selectAll('text')
    .data(countryShapes.features)
    .enter()
    .append('text')
    .text((d) => d.properties.NAME_1)
    .attr('x', d=>  pathGenerator.centroid(d)[0]   )
    .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
    .attr("font-size", "8px");
});